@@ -110,7 +110,17 @@ def initialize():
     return {  
         'status': 'Success',
         'code': 200,
-        'message': 'Succeed initializing credentials'
+        'message': 'Succeed creating and processing request'
+    }
+
+@app.route('/update',methods=['POST'])
+def update():
+    input=request.json
+    print(input)
+    return {  
+        'status': 'Success',
+        'code': 200,
+        'message': 'Succeed updating metadata file'
     }
 
 @app.route('/request',methods=['DELETE'])
